# Network analysis of MSI data
#
# MIT License
# 
# Copyright (c) 2021 Paolo Inglese
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#   
#   The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# Author: Peter Kreuzaler (The Francis Crick Institute, London)
#

library(tidyverse)
library(ggthemes)
library(extremevalues)
library(ggrepel)
library(ggpubr)
library(volcano3D)


metadata <- read.csv("./LC_Xmas_sample_info.csv")
syn_pvalues <- read.csv("./LC_Xmas_pvalues.csv")
MS_values <- read_csv("./LC_Xmas_values.csv")
MS_values <- as.data.frame(MS_values)
MS_values2 <- MS_values[,-1]
rownames(MS_values2) <- MS_values[,1]
syn_pvalues2 <- syn_pvalues[,-1]
rownames(syn_pvalues2) <- syn_pvalues[,1]

syn_polar <- polar_coords(sampledata = metadata,
                          contrast = "Pathotype",
                          pvalues = syn_pvalues2,
                          expression = MS_values2,
                          p_col_suffix = "pvalue",
                          padj_col_suffix = "padj",
                          fc_col_suffix = "log2FoldChange",
                          multi_group_prefix = "Overall",
                          non_sig_name = "Not Significant",
                          significance_cutoff = 0.05,
                          label_column = NULL,
                          fc_cutoff = 0.5)

syn_plots <- 
  volcano_trio(
    polar = syn_polar,
    sig_names = c("not significant","significant",
                  "not significant","significant"),
    colours = rep(c("grey60",  "slateblue1"), 2),
    text_size = 9,
    marker_size=1,
    shared_legend_size = 0.9,
    #label_rows = c("SLAMF6", "PARP16", "ITM2C"),
    fc_line = FALSE,
    share_axes = FALSE)
syn_plots$All

radial_plotly(polar = syn_polar,
              #label_rows = c("SLAMF6", "PARP16", "ITM2C")
              )

radial_ggplot(polar = syn_polar,
              #label_rows = c("SLAMF6", "FMOD"),
              marker_size = 8,
              legend_size = 10) +
  theme(legend.position = "right")

image <- radial_ggplot(polar = syn_polar,
                       #label_rows = c("L-Glutamine", "L-Serine", "L-Lysine", "L-Methionine", "L-Histidine", "Pantothenic-acid"),
                       marker_size = 8,
                       legend_size = 20) +
  theme(legend.position = "right")

ggsave(filename = "Radial_xmas_apol.svg", width=10, height=8)

p <- volcano3D(syn_polar,
               #label_rows = c("810.5269722"),
               label_size = 10,
               colour_code_labels = F,
               label_colour = "black",
               xy_aspectratio = 1,
               z_aspectratio = 0.9,
               plot_height = 800)
p
# negative mode to 612
df <- syn_polar@polar
df <- df %>% mutate(index = c(1:length(df$Name)))
Redpos <- df %>% filter(index > 612, sig == "Mix+")
write.csv(Redpos,"./Mixpos.csv", row.names = FALSE)