library(glmmTMB)
library(tidyverse)
library(ggpubr)
library(ggeffects)


library(sjPlot)
library(sjmisc)
library(sjlabelled)

dat <- readRDS('Human_PA_all.rds') %>%
  select(tissue, color, pa) %>% 
  mutate(Myc = factor(ifelse(.$color == "G", "High", "Low")))

thresholds <- dat %>%
  group_by(tissue) %>%
  summarise(th = median(pa)) %>%
  ungroup()

mask_pa <- numeric(nrow(dat))
  for (j in thresholds$tissue) {
    mask_pa[which(dat$tissue == j)] <- 
      dat$pa[which(dat$tissue == j)] > thresholds %>%
      filter(tissue == j) %>%
      pull(th)
  }

dat <- dat %>%
  mutate(PA_binary = mask_pa)

prop_pa <- tibble(tissue = numeric(),
                  Myc = character(), prop = numeric())
for (j in unique(dat$tissue)) {
  prop_pa <- bind_rows(
    prop_pa,
    tibble(
      tissue = j,
      Myc = "high",
      prop = dat %>%
        filter(tissue == j) %>%
        filter(Myc == "High") %>%
        {
          sum(.$PA_binary) / nrow(.)
        }
    ),
    tibble(
      tissue = j,
      Myc = "low",
      prop = dat %>%
        filter(tissue == j) %>%
        filter(Myc == "Low") %>%
        {
          sum(.$PA_binary) / nrow(.)
        }
    )
  )
}

prop_pa <- prop_pa %>%
  mutate(tissue = as.factor(tissue))

mdl <- glmmTMB(prop ~ Myc + (1|tissue), data=as.data.frame(prop_pa),
               family = beta_family())

ggplot(data = NULL, aes(y = resid(mdl, type = "pearson"),
                        x = fitted(mdl))) + geom_point()

prop_pa

pred <- ggpredict(mdl, terms=c('Myc'))
p <- ggplot() +
  geom_point(aes(x=Myc, y=prop, color=tissue), size=5, data=prop_pa) +
  geom_line(aes(x=Myc, y=prop, group=tissue, color=tissue), data=prop_pa) +
  scale_color_brewer(palette='Set1') +
  geom_point(aes(x = x, y = predicted), size=5, color='black', data=pred) +
  geom_errorbar(aes(x=x, ymin=conf.low, ymax=conf.high), color='black', data=pred, width=0.1, size=1) +
  labs(#title=paste0(mz_module[i], ' m/z'),
    x='Myc Level') +
  ylab("Proportion PA-high") +
  scale_x_discrete(labels = c("high", "low")) +
  theme_classic() +
  guides(color = guide_legend(title = "Sample"))
ggsave(filename = 'preds_pa_human_2023.pdf', plot = p, dpi = 300, width = 4, height = 4)


tab_model(mdl, file = 'summary_fit_PA_human.html')
