# Myc expression and Myc pathway activation of analysed PDXs
#
# MIT License
# 
# Copyright (c) 2021 Oscar Rueda
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#   
#   The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# Author: Oscar Rueda (University of Cambridge)
#

## To reproduce the expression analysis from scratch follow Bruna et al Cell 2016 paper (scripts in https://figshare.com/articles/dataset/Bruna_et_al_A_biobank_of_breast_cancer_explants_with_preserved_intra-tumor_heterogeneity_to_screen_anticancer_compounds_Cell_2016/2069274)
## Compute pathway activation

library(preprocessCore)
library(GSA)
library(GSVA)

load(file="/VExpression/PDX_Genes_Expression.RData")

PDX <- PDX[,which(SS$TYPE!="Normal")]
SS <- SS[which(SS$TYPE!="Normal"),]

## This is METABRIC Expression data (publicly available)
load("/MetabricExpressionDiscoverySet997.RData")
load("/Metabric2/MetabricExpressionValidationSet983.RData")
Metabric <- cbind(DS, VS)
rm(DS, VS)

Genes$IlluminaID <- as.character(Genes$IlluminaID)
common.probes <- intersect(rownames(Metabric), Genes$IlluminaID)
Genes <- Genes[which(Genes$IlluminaID %in% common.probes),]
Metabric <- Metabric[which(rownames(Metabric) %in% Genes$IlluminaID),]
PDX <- PDX[which(rownames(PDX) %in% Genes$symbol2),]
Genes <- Genes[match(rownames(PDX), Genes$symbol2),]
Metabric <- Metabric[match(Genes$IlluminaID, rownames(Metabric)),]
mean(rownames(Metabric) == Genes$IlluminaID)
mean(rownames(PDX) == Genes$symbol2)
rownames(Metabric) <- Genes$symbol2
mean(rownames(Metabric) == rownames(PDX))

Exp <- cbind(Metabric, PDX)

AllExp <- normalize.quantiles(Exp)
dimnames(AllExp) <- dimnames(Exp)
AllExp <- apply(AllExp, 1, scale)
AllExp <- t(AllExp)
dimnames(AllExp) <- dimnames(Exp)

geneset.obj<- GSA.read.gmt("/c6.all.v4.0.symbols.gmt.txt")
DDR <- read.table("/DDR_pathway.txt")
geneset.obj$geneset.names <- c(geneset.obj$geneset.names, "DDR")
N <- length(geneset.obj$genesets)
geneset.obj$genesets[[N+1]] <- DDR$V1
PI3K <- read.table("/PI3K_AKT_mTOR.txt")
PI3K <- unique(PI3K$V1)
geneset.obj$geneset.names <- c(geneset.obj$geneset.names, "PI3K/AKT/mTOR")
N <- length(geneset.obj$genesets)
geneset.obj$genesets[[N+1]] <- PI3K

m2 <- gsva(expr=AllExp, gset.idx.list=geneset.obj$genesets, method="gsva", verbose=TRUE, parallel.sz=2)
res <- m2$es.obs
rownames(res) <- geneset.obj$geneset.names
save(res, file="/Expression/pathways.RData")

load(file="/Volumes/CLUS_BACKUP/PDX/PDX/Expression/pathways.RData")
MYC.pathway <- res['MYC_UP.V1_UP',] - res['MYC_UP.V1_DN',]
MYC.pathway <- MYC.pathway[1981:length(MYC.pathway)]
AllExp <- AllExp[,1981:length(MYC.pathway)]

SS <- read.csv("/Expression/ExpressionFullSampleSheet.csv", skip=7)
SS <- SS[which(SS$ID %in% colnames(AllExp)),]
SS <- SS[match(colnames(AllExp), SS$ID),]

MYC.pathway <- tapply(MYC.pathway, SS$Tumour, mean)
sub.Exp <- tapply(AllExp, SS$Tumour, mean)

pdf("../Expression/MYCActivation.pdf", width=10, height=10)
plot(sub.Exp, MYC.pathway, xlab="MYC log-intensity Expression", ylab="MYC pathway activation",
type="n")
text(sub.Exp, MYC.pathway, names(sub.Exp))
dev.off()

